@@ -210,7 +210,60 @@ def findWells(videoPath, hyperparameters):
     well = { 'topLeftX' : 0 , 'topLeftY' : 0 , 'lengthX' : frame_width , 'lengthY': frame_height }
     l.append(well)
     return l
-    
+  
+  # Multiple ROIs defined by user during the execution
+  
+  if int(hyperparameters["multipleROIsDefinedDuringExecution"]):
+    l = []
+    cap = cv2.VideoCapture(videoPath)
+    if (cap.isOpened()== False): 
+      print("Error opening video stream or file")
+    ret, frame = cap.read()
+    root = tk.Tk()
+    horizontal = root.winfo_screenwidth()
+    vertical   = root.winfo_screenheight()
+    getRealValueCoefX = 1
+    getRealValueCoefY = 1
+    if len(frame[0]) > horizontal or len(frame) > vertical:
+      reduce = min(horizontal / len(frame[0]), vertical / len(frame))
+      newLengthX = int(len(frame[0]) * reduce)
+      newLengthY = int(len(frame)    * reduce)
+      getRealValueCoefX = len(frame[0]) / newLengthX
+      getRealValueCoefY = len(frame)    / newLengthY
+      frame = cv2.resize(frame, (newLengthX, newLengthY))
+    root.destroy()
+    cv2.waitKey(500)
+    for i in range(0, int(hyperparameters["nbWells"])):
+      WINDOW_NAME = "Click on the top left of one of the regions of interest"
+      cvui.init(WINDOW_NAME)
+      cv2.moveWindow(WINDOW_NAME, 0,0)
+      cvui.imshow(WINDOW_NAME, frame)
+      while not(cvui.mouse(cvui.CLICK)):
+        cursor = cvui.mouse()
+        cv2.waitKey(20)
+      topLeft = [cursor.x, cursor.y]
+      cv2.destroyWindow(WINDOW_NAME)
+      WINDOW_NAME = "Click on the bottom right of the same region of interest"
+      cvui.init(WINDOW_NAME)
+      cv2.moveWindow(WINDOW_NAME, 0,0)
+      cvui.imshow(WINDOW_NAME, frame)
+      while not(cvui.mouse(cvui.CLICK)):
+        cursor = cvui.mouse()
+        cv2.waitKey(20)
+      bottomRight = [cursor.x, cursor.y]
+      frame = cv2.rectangle(frame, (topLeft[0], topLeft[1]), (bottomRight[0], bottomRight[1]), (255, 0, 0), 1)
+      cv2.destroyWindow(WINDOW_NAME)
+      topLeftX = int(topLeft[0] * getRealValueCoefX)
+      topLeftY = int(topLeft[1] * getRealValueCoefY)
+      frame_width  = int((bottomRight[0] - topLeft[0]) * getRealValueCoefX)
+      frame_height = int((bottomRight[1] - topLeft[1]) * getRealValueCoefY)
+      well = {'topLeftX' : topLeftX, 'topLeftY' : topLeftY, 'lengthX' : frame_width, 'lengthY': frame_height}
+      l.append(well)
+    cap.release()
+    return l
+  
+  # One ROI definied in the configuration file
+  
   if len(hyperparameters["oneWellManuallyChosenTopLeft"]):
     l = []
     topLeft_X = hyperparameters["oneWellManuallyChosenTopLeft"][0]
