@@ -73,7 +73,7 @@ def getBackground(videoPath, hyperparameters):
     else:
       print("couldn't use the frame", k, "for the background extraction")
   
-  if hyperparameters["imagePreProcessMethod"]:
+  if hyperparameters["backgroundPreProcessMethod"]:
     back = preprocessBackgroundImage(back, hyperparameters)
   
   if hyperparameters["checkThatMovementOccurInVideo"]:
@@ -119,7 +119,7 @@ def getBackground(videoPath, hyperparameters):
   
   if (debugExtractBack):
       
-    cv2.imshow('Background extracted', back)
+    cv2.imshow('Background extracted: Click on any key to proceed!', back)
     if hyperparameters["exitAfterBackgroundExtraction"]:
       cv2.waitKey(3000)
     else:
